normalize_trace

Function normalize_trace 

pub fn normalize_trace(trace: &mut [Span]) -> Result<()>
normalize_trace takes a trace and

  • returns an error if there is a trace ID discrepancy between 2 spans
  • returns an error if at least one span cannot be normalized